@@ -17,9 +17,6 @@ S4 toDgCMat(csc*);
 //typedef Rcpp::XPtr<OSQPWorkspace, Rcpp::PreserveStorage, mycleanup> XPtrOsqpWork;
 
 
-
-
-
 // [[Rcpp::export]]
 SEXP osqpSetup(const S4& P, const NumericVector& q, const S4& A, const NumericVector& l, const NumericVector& u, const List& pars)
 {
@@ -88,6 +85,7 @@ List osqpSolve(SEXP workPtr)
                       _("dua_res") = work->info->dua_res,
                       _("setup_time") = work->info->setup_time,
                       _("solve_time") = work->info->solve_time,
+                      _("update_time") = work->info->update_time,
                       _("polish_time") = work->info->polish_time,
                       _("run_time") = work->info->run_time,
                       _("rho_estimate") = work->info->rho_estimate,
@@ -167,19 +165,78 @@ IntegerVector osqpGetDims(SEXP workPtr)
   return res;
 }
 // [[Rcpp::export]]
-void osqpUpdate(SEXP workPtr, Rcpp::Nullable<NumericVector> q_new, Rcpp::Nullable<NumericVector> l_new, Rcpp::Nullable<NumericVector> u_new)
+void osqpUpdate(SEXP workPtr,
+    Rcpp::Nullable<NumericVector> q_new,
+    Rcpp::Nullable<NumericVector> l_new,
+    Rcpp::Nullable<NumericVector> u_new,
+    Rcpp::Nullable<NumericVector> Px,
+    Rcpp::Nullable<IntegerVector> Px_idx,
+    Rcpp::Nullable<NumericVector> Ax,
+    Rcpp::Nullable<IntegerVector> Ax_idx)
 {
   auto work = as<Rcpp::XPtr<OSQPWorkspace, Rcpp::PreserveStorage, mycleanup> >(workPtr);
 
+  // Update problem vectors
   if (q_new.isNotNull()) {
     osqp_update_lin_cost(work, as<NumericVector>(q_new.get()).begin());
   }
-  if (l_new.isNotNull()) {
+  if (l_new.isNotNull() & u_new.isNull()) {
     osqp_update_lower_bound(work, as<NumericVector>(l_new.get()).begin());
   }
-  if (u_new.isNotNull()) {
+  if (u_new.isNotNull() & l_new.isNull()) {
     osqp_update_upper_bound(work, as<NumericVector>(u_new.get()).begin());
   }
+  if (u_new.isNotNull() & l_new.isNotNull()) {
+    osqp_update_bounds(work,
+        as<NumericVector>(l_new.get()).begin(),
+        as<NumericVector>(u_new.get()).begin());
+  }
+
+
+  // Update problem matrices
+  c_int * Px_idx_ = OSQP_NULL;
+  c_int len_Px = 0;
+  c_int * Ax_idx_ = OSQP_NULL;
+  c_int len_Ax = 0;
+  // Get which parameters are null
+  if (Px_idx.isNotNull()) {
+    Px_idx_ = (c_int *)as<IntegerVector>(Px_idx.get()).begin();
+    NumericVector Px_ = Px.get();
+    len_Px = Px_.size();
+  }
+  if (Ax_idx.isNotNull()) {
+    Ax_idx_ = (c_int *)as<IntegerVector>(Ax_idx.get()).begin();
+    NumericVector Ax_ = Ax.get();
+    len_Ax = Ax_.size();
+  }
+  // Only P
+  if (Px.isNotNull() & Ax.isNull()){
+      osqp_update_P(work,
+          as<NumericVector>(Px.get()).begin(),
+          Px_idx_,
+          len_Px);
+  }
+
+  // Only A
+  if (Ax.isNotNull() & Px.isNull()){
+      osqp_update_A(work, as<NumericVector>(Ax.get()).begin(),
+                    Ax_idx_,
+                    len_Ax);
+  }
+
+  // Both A and P
+  if (Px.isNotNull() & Ax.isNotNull()){
+      osqp_update_P_A(
+          work,
+          as<NumericVector>(Px.get()).begin(),
+          Px_idx_,
+          len_Px,
+          as<NumericVector>(Ax.get()).begin(),
+          Ax_idx_,
+          len_Ax);
+  }
+
+
 }
 
 void extractMatrixData(const S4& mat, std::vector<c_int>& iout, std::vector<c_int>& pout, std::vector<c_float>& xout)
